@@ -1,2 +1,2 @@
+from .named_iterable import named_iterable
 from .processed_property import processed_property
-from .version import __version__
